==> homerun-1.2.0.tar.xz: homerun-1.2.0/fullscreen/applet/plasma-applet-homerunlauncher.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
# ctxt: "Homerun" is a product name
Name=Homerun Launcher
Name[cs]=Spouštěč Homerun
Name[da]=Startmenuen Homerun
Name[de]=Homerun-Starter
Name[el]=Εκτελεστής Homerun
Name[es]=Lanzador Homerun
Name[fi]=Homerun-käynnistin
Name[fr]=Lanceur de Homerun
Name[gl]=Lanzador Homerun
Name[hu]=Homerun indító
Name[nl]=Programmastarter Homerun
Name[pl]=Program uruchamiający Homerun
Name[pt]=Lançador Homerun
Name[pt_BR]=Lançador Homerun
Name[ro]=Lansator Homerun
Name[ru]=Запуск Homerun
Name[sk]=Spúšťač Homerun
Name[sl]=Zaganjalnik Homerun
Name[sv]=Homerun startprogram
Name[tr]=Homerun Çalıştırıcı
Name[uk]=Засіб запуску Homerun
Name[x-test]=xxHomerun Launcherxx
Name[zh_CN]=Homerun 启动器

Comment=An application launcher
Comment[cs]=Spouštěč aplikací
Comment[da]=Programstarter
Comment[de]=Ein Anwendungsstarter
Comment[el]=Ένας εκτελεστής εφαρμογών
Comment[es]=Un lanzador de aplicaciones
Comment[et]=Rakenduste käivitaja
Comment[fi]=Sovelluskäynnistin
Comment[fr]=Un lanceur d'applications
Comment[gl]=Un lanzador de programas.
Comment[hu]=Egy alkalmazásindító
Comment[lt]=Programų leidiklis
Comment[mr]=अनुप्रयोग प्रक्षेपक
Comment[nl]=Een programmastarter
Comment[pa]=ਐਪਲੀਕੇਸ਼ਨ ਲਾਂਚਰ
Comment[pl]=Program uruchamiający
Comment[pt]=Um lançador de aplicações
Comment[pt_BR]=Um lançador de aplicativos
Comment[ro]=Lansator de aplicații
Comment[ru]=Запуск приложения
Comment[sk]=Spúšťač aplikácií
Comment[sl]=Zaganjalnik programov
Comment[sv]=Ett startprogram
Comment[tr]=Bir uygulama çalıştırıcı
Comment[uk]=Засіб для запуску програм
Comment[x-test]=xxAn application launcherxx
Comment[zh_CN]=一个应用程序启动器

Type=Service
ServiceTypes=Plasma/Applet
Icon=homerun

X-KDE-Library=plasma_applet_homerunlauncher
X-KDE-PluginInfo-Author=Homerun Developers
X-KDE-PluginInfo-Name=homerunlauncher
X-KDE-PluginInfo-Version=@HOMERUN_VERSION@
X-KDE-PluginInfo-Website=http://userbase.kde.org/Homerun
X-KDE-PluginInfo-Category=Application Launchers
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true

X-Plasma-Requires-FileDialog=Unused
X-Plasma-Requires-LaunchApp=Unused

==> homerun_1.2.1.orig.tar.xz: homerun-1.2.1/fullscreen/applet/plasma-applet-homerunlauncher.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
# ctxt: "Homerun" is a product name
Name=Homerun Launcher
Name[bs]=Homerun pokretač
Name[ca]=Llançador Homerun
Name[cs]=Spouštěč Homerun
Name[da]=Startmenuen Homerun
Name[de]=Homerun-Starter
Name[el]=Εκτελεστής Homerun
Name[es]=Lanzador Homerun
Name[fi]=Homerun-käynnistin
Name[fr]=Lanceur de Homerun
Name[gl]=Lanzador Homerun
Name[hu]=Homerun indító
Name[it]=Avviatore di Homerun
Name[ko]=Homerun 실행기
Name[nl]=Programmastarter Homerun
Name[pl]=Program uruchamiający Homerun
Name[pt]=Lançador Homerun
Name[pt_BR]=Lançador Homerun
Name[ro]=Lansator Homerun
Name[ru]=Запуск Homerun
Name[sk]=Spúšťač Homerun
Name[sl]=Zaganjalnik Homerun
Name[sv]=Homerun startprogram
Name[tr]=Homerun Çalıştırıcı
Name[uk]=Засіб запуску Homerun
Name[x-test]=xxHomerun Launcherxx
Name[zh_CN]=Homerun 启动器

Comment=An application launcher
Comment[bs]=Pokretač aplikacija
Comment[ca]=Un llançador d'aplicacions
Comment[cs]=Spouštěč aplikací
Comment[da]=Programstarter
Comment[de]=Ein Anwendungsstarter
Comment[el]=Ένας εκτελεστής εφαρμογών
Comment[es]=Un lanzador de aplicaciones
Comment[et]=Rakenduste käivitaja
Comment[fi]=Sovelluskäynnistin
Comment[fr]=Un lanceur d'applications
Comment[gl]=Un lanzador de programas.
Comment[hu]=Egy alkalmazásindító
Comment[it]=Un avviatore di applicazioni
Comment[ko]=프로그램 실행기
Comment[lt]=Programų leidiklis
Comment[mr]=अनुप्रयोग प्रक्षेपक
Comment[nl]=Een programmastarter
Comment[pa]=ਐਪਲੀਕੇਸ਼ਨ ਲਾਂਚਰ
Comment[pl]=Program uruchamiający
Comment[pt]=Um lançador de aplicações
Comment[pt_BR]=Um lançador de aplicativos
Comment[ro]=Lansator de aplicații
Comment[ru]=Запуск приложения
Comment[sk]=Spúšťač aplikácií
Comment[sl]=Zaganjalnik programov
Comment[sv]=Ett startprogram
Comment[tr]=Bir uygulama çalıştırıcı
Comment[uk]=Засіб для запуску програм
Comment[x-test]=xxAn application launcherxx
Comment[zh_CN]=一个应用程序启动器

Type=Service
ServiceTypes=Plasma/Applet
Icon=homerun

X-KDE-Library=plasma_applet_homerunlauncher
X-KDE-PluginInfo-Author=Homerun Developers
X-KDE-PluginInfo-Name=homerunlauncher
X-KDE-PluginInfo-Version=@HOMERUN_VERSION@
X-KDE-PluginInfo-Website=http://userbase.kde.org/Homerun
X-KDE-PluginInfo-Category=Application Launchers
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true

X-Plasma-Requires-FileDialog=Unused
X-Plasma-Requires-LaunchApp=Unused
